@@ -1,7 +1,7 @@
 # function to summarize estimation results  2015-3-11 Thong Pham
 summary.CV_Data <- function(object,...){
-  cat("\nCV_Data object contains data required in the performCV function. \n");
-  cat("Number of bins: ", object$stat$G,"\n");
+  cat("\nContaining the data required in cross-validation. \n");
+  cat("Number of bins: ", object$stat$g,"\n");
   cat("Ratio p:", object$p, "\n");
 }
 
